@@ -1,5 +1,6 @@
-#include <stdint.h>
-#include <time.h>
+#include <sys/types.h>
+
+#include <stdio.h>
 
 #ifdef __OpenBSD__
 #include <unistd.h>
@@ -17,8 +18,6 @@ struct feed {
 	char *        name;     /* feed name */
 	unsigned long totalnew; /* amount of new items per feed */
 	unsigned long total;    /* total items */
-	time_t        timenewest;
-	char          timenewestformat[64];
 };
 
 enum {
